CommonStorage class

Fps 信息存储

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ Queue<FpsInfo>
getter/setter pair
max ↔ double?
getter/setter pair
maxCount ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalNum ↔ double
getter/setter pair

Methods

clear() → void
contains(FpsInfo info) → bool
getAll() → List<FpsInfo>
getAvg() → num
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(FpsInfo info) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → CommonStorage?
no setter